@@ -49,7 +49,7 @@ class PubSub(object):
             self.kafka_poll_timeout = kafka_poll_timeout
             self._kafka_producer = None
             self._kafka_consumer = None
-            self.validated_topics = False
+            self.create_kafka_topics()
 
     def get_kafka_producer(self):
         # We don't want to establish a connection everytime we need to use the producer
@@ -103,7 +103,6 @@ class PubSub(object):
                 logger.info("Creating new kafka topic %s" % (topic, ))
 
         kafka_admin.create_topics(new_topic_list)
-        self.validated_topics = True
 
     def emit(self, event, message, emit=False):
 
@@ -120,9 +119,6 @@ class PubSub(object):
         self.pubsub.close()
 
         if self.enable_kafka:
-            if not self.validated_topics:
-                raise ValueError("You forgot to run create_kafka_topics method")
-
             kafka_producer = self.get_kafka_producer()
             future = kafka_producer.send(event, bytes(message_str, "utf-8"))
             # Should we wait and make sure it is sent ?
